/* *****************************************************************************
 * libp7/internals/endian.h -- platform-agnostic endianness utilities.
 * Copyright (C) 2016-2017 Thomas "Cakeisalie5" Touhey <thomas@touhey.fr>
 *
 * This file is part of libp7.
 * libp7 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3.0 of the License,
 * or (at your option) any later version.
 *
 * libp7 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with libp7; if not, see <http://www.gnu.org/licenses/>.
 *
 * This file is there to use the platform's endianness helpers.
 * If the platform is unrecognized, the lib will try to use the `endian.h`
 * header -- if you don't want to modify the library, you should implement it.
 * ************************************************************************** */
#ifndef LIBP7_INTERNALS_ENDIAN_H
# define LIBP7_INTERNALS_ENDIAN_H
# include <libp7/config.h>
# include <libp7/internals/byteswap.h>

/* MS-Windows specific headers */
# if (defined(_WIN16) || defined(_WIN32) || defined(_WIN64)) \
	&& !defined(__WINDOWS__)
#  define __WINDOWS__
# endif

# if defined(__APPLE__)
#  include <libkern/OSByteOrder.h>

#  define be16toh(x) OSSwapBigToHostInt16(x)
#  define be32toh(x) OSSwapBigToHostInt32(x)
#  define be64toh(x) OSSwapBigToHostInt64(x)

#  define htobe16(x) OSSwapHostToBigInt16(x)
#  define htobe32(x) OSSwapHostToBigInt32(x)
#  define htobe64(x) OSSwapHostToBigInt64(x)

# elif defined(__OpenBSD__)
#  include <sys/endian.h>

# elif defined(__WINDOWS__)
#  include <winsock2.h>
#  include <sys/param.h>

#  if BYTE_ORDER == LITTLE_ENDIAN
#   define be16toh(x) ntohs(x)
#   define be32toh(x) ntohl(x)
#   define be64toh(x) ntohll(x)

#   define htobe16(x) htons(x)
#   define htobe32(x) htonl(x)
#   define htobe64(x) htonll(x)
#  else
#   define be16toh(x) (x)
#   define be32toh(x) (x)
#   define be64toh(x) (x)

#   define htobe16(x) (x)
#   define htobe32(x) (x)
#   define htobe64(x) (x)
#  endif

# else
#  include <endian.h>
# endif

#endif /* LIBP7_INTERNALS_ENDIAN_H */
