/* *****************************************************************************
 * libp7/internals/sleep.h -- platform-agnostic sleep utility.
 * Copyright (C) 2016-2017 Thomas "Cakeisalie5" Touhey <thomas@touhey.fr>
 *
 * This file is part of libp7.
 * libp7 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3.0 of the License,
 * or (at your option) any later version.
 *
 * libp7 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with libp7; if not, see <http://www.gnu.org/licenses/>.
 *
 * This file is there to use the platform's sleep function (in milliseconds).
 * If the platform is unrecognized, the lib will try to use the `usleep`
 * function defined in `unistd.h` -- if you don't want to modify this library,
 * you should implement it.
 * ************************************************************************** */
#ifndef LIBP7_INTERNALS_SLEEP_H
# define LIBP7_INTERNALS_SLEEP_H

/* MS-Windows stuff */
# if (defined(_WIN16) || defined(_WIN32) || defined(_WIN64)) \
	&& !defined(__WINDOWS__)
#  define __WINDOWS__
# endif

# if defined(__WINDOWS__)
#  include <windows.h>
#  define p7_sleep(N) Sleep(N)
# else
#  include <unistd.h>
#  define p7_sleep(N) usleep((N) * 1000)
# endif

#endif /* LIBP7_INTERNALS_SLEEP_H */
