/* *****************************************************************************
 * libp7/streams.h -- libp7 built-in streams.
 * Copyright (C) 2016-2017 Thomas "Cakeisalie5" Touhey <thomas@touhey.fr>
 *
 * This file is part of libp7.
 * libp7 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3.0 of the License,
 * or (at your option) any later version.
 *
 * libp7 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with libp7; if not, see <http://www.gnu.org/licenses/>.
 * ************************************************************************** */
#ifndef LIBP7_STREAMS_H
# define LIBP7_STREAMS_H
# include <libp7/types.h>
# if (defined(_WIN16) || defined(_WIN32) || defined(_WIN64)) \
	&& !defined(__WINDOWS__)
#  define __WINDOWS__
# endif
# ifdef __cplusplus
extern "C" {
# endif

/* Make a libp7 stream using the standard FILE interface. */
# ifndef P7_DISABLED_FILE
extern int p7_sopen_file(p7_stream_t *stream,
	FILE *readstream, FILE *writestream);
# endif

/* Make a libp7 stream using the POSIX STREAMS interface. */
# if defined(__linux__)
extern int p7_sopen_streams(p7_stream_t *stream, const char *path,
	int readfd, int writefd);
extern int p7_slist_streams(p7_list_device_t callback, void *cookie);
# else
#  define P7_DISABLED_STREAMS
# endif

/* Make a libp7 stream using libusb. */
# ifndef P7_DISABLED_LIBUSB
extern int p7_sopen_libusb(p7_stream_t *stream);
# endif

/* Make a libp7 stream using the Windows API. */
# ifdef __WINDOWS__
extern int p7_sopen_windows(p7_stream_t *stream, const char *path);
extern int p7_slist_windows(p7_list_device_t callback, void *cookie);
# else
#  define P7_DISABLED_WINDOWS
# endif

/* Using the macros, check if there is serial/usb on this platform */
# if defined(P7_DISABLED_STREAMS) && defined(P7_DISABLED_WINDOWS)
#  define P7_NOSERIAL
# endif
# if defined(P7_DISABLED_LIBUSB) && defined(P7_DISABLED_STREAMS) \
  && defined(P7_DISABLED_WINDOWS)
#  define P7_NOUSB
# endif

# ifdef __cplusplus
}
# endif
#endif /* LIBP7_STREAMS_H */
