/* *****************************************************************************
 * usage/poke.c -- poke the calculator so the communication doesn't stop.
 * Copyright (C) 2016-2017 Thomas "Cakeisalie5" Touhey <thomas@touhey.fr>
 *
 * This file is part of libp7.
 * libp7 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3.0 of the License,
 * or (at your option) any later version.
 *
 * libp7 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with libp7; if not, see <http://www.gnu.org/licenses/>.
 * ************************************************************************** */
#include <libp7/internals.h>

/**
 *	p7_poke:
 *	Poke the device.
 *
 *	@arg	handle		the libp7 handle.
 *	@return				if it worked.
 */

int p7_poke(p7_handle_t *handle)
{
	int err;
	/* make checks */
	chk_handle(handle);
	chk_active(handle);

	/* send the check packet */
	if ((err = p7_seven_send_check(handle))) {
		log_fatal("couldn't send check");
		return (err);
	} else if (response.type != p7_seven_type_ack) {
		log_fatal("check answer was unexpected");
		return (p7_error_unknown);
	}

	/* no error */
	return (0);
}
