/* *****************************************************************************
 * usage/server/direct.c -- set up a protocol 7 server.
 * Copyright (C) 2016-2017 Thomas "Cakeisalie5" Touhey <thomas@touhey.fr>
 *
 * This file is part of libp7.
 * libp7 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3.0 of the License,
 * or (at your option) any later version.
 *
 * libp7 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with libp7; if not, see <http://www.gnu.org/licenses/>.
 * ************************************************************************** */
#include <libp7/internals.h>

/**
 *	p7_serve_directly:
 *	Initialize a direct P7 server.
 *
 *	@arg	handle		the libp7 handle.
 *	@arg	callbacks	the server callbacks.
 *	@arg	cookie		the server cookie.
 *	@return				the error.
 */

int p7_serve_directly(p7_handle_t *handle, p7_server_callback_t *callbacks,
	void *cookie)
{
	int err;
	/* make checks */
	chk_handle(handle);
	chk_passive(handle);

	/* initial check */
	if ((err = p7_seven_recv(handle, 0))) return (err);
	while (response.type != p7_seven_type_check || !response.initial) {
		err = p7_seven_send_err(handle, p7_seven_err_other);
		if (err) return (err);
	}

	/* ack and start! */
	err = p7_seven_send_ack(handle, 1);
	if (err) return (err);

	/* main loop */
	while (1) {
		/* check command packet */
		if (response.type != p7_seven_type_cmd) {
			if (response.type == p7_seven_type_end) break;
			p7_seven_send_err(handle, p7_seven_err_other);
			continue ;
		}

		/* check if callback exists */
		if (!callbacks[response.code]) {
			err = p7_seven_send_err(handle, p7_seven_err_other);
			if (err) return (err);
			continue ;
		}

		/* call the callback */
		err = (*callbacks[response.code])(cookie, handle);
		if (err) {
			if (err != p7_error_unknown) return (err);
			p7_seven_send_err(handle, p7_seven_err_other);
			continue ;
		}
	}

	/* ack and disconnect */
	return (p7_seven_send_ack(handle, 0));
}
