/* *****************************************************************************
 * utils/checksum.c -- libp7 checksum utility.
 * Copyright (C) 2016-2017 Thomas "Cakeisalie5" Touhey <thomas@touhey.fr>
 *
 * This file is part of libp7.
 * libp7 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3.0 of the License,
 * or (at your option) any later version.
 *
 * libp7 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with libp7; if not, see <http://www.gnu.org/licenses/>.
 * ************************************************************************** */
#include <libp7/internals.h>

/**
 *	p7_checksum:
 *	Returns the checksum of a packet
 *
 *	The checksum is an unsigned integer that can fit in 8 bits.
 *
 *	@arg	packet		pointer to the packet
 *	@arg	size		the packet size (in bytes)
 *	@return				the checksum
 */

unsigned int p7_checksum(unsigned char *packet, p7ushort_t size)
{
	unsigned int sum = 0;
	/* remove type and checksum fields */
	packet++; size -= 3;

	/* add everything */
	while (size--)
		sum += *packet++;

	/* NOT + 1, as defined in fxReverse documentation.
	 * Be sure it's under 256! */
	return ((~sum + 1) & 0xFF);
}
