/* *****************************************************************************
 * utils/filebuffer.c -- built-in FILE buffer utilities.
 * Copyright (C) 2016-2017 Thomas "Cakeisalie5" Touhey <thomas@touhey.fr>
 *
 * This file is part of libp7.
 * libp7 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3.0 of the License,
 * or (at your option) any later version.
 *
 * libp7 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with libp7; if not, see <http://www.gnu.org/licenses/>.
 * ************************************************************************** */
#include <libp7/internals.h>
#ifndef P7_DISABLED_FILE

/**
 *	p7_filebuffer_read:
 *	Read from a FILE*. P7_Buffer callback.
 *
 *	TODO: manage errors.
 *
 *	@arg	vcookie		the cookie (uncasted).
 *	@arg	dest		the destination buffer.
 *	@arg	size		the size to read.
 *	@return				the error code (0 if ok).
 */

int p7_filebuffer_read(void *vcookie, unsigned char *dest, size_t size)
{
	FILE *f = (FILE*)vcookie;
	fread(dest, size, 1, f);
	return (0);
}

/**
 *	p7_filebuffer_write:
 *	Write to a FILE*. P7_Buffer callback.
 *
 *	@arg	vcookie		the cookie (uncasted).
 *	@arg	dest		the destination buffer.
 *	@arg	size		the size to read.
 *	@return				the error code (0 if ok).
 */

int p7_filebuffer_write(void *vcookie, const unsigned char *data, size_t size)
{
	FILE *f = (FILE*)vcookie;
	fwrite(data, size, 1, f);
	return (0);
}

#endif
