/* *****************************************************************************
 * utils/membuffer.c -- built-in memory buffer utilities.
 * Copyright (C) 2016-2017 Thomas "Cakeisalie5" Touhey <thomas@touhey.fr>
 *
 * This file is part of libp7.
 * libp7 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3.0 of the License,
 * or (at your option) any later version.
 *
 * libp7 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with libp7; if not, see <http://www.gnu.org/licenses/>.
 * ************************************************************************** */
#include <libp7/internals.h>
#include <string.h>

/**
 *	p7_membuffer_read:
 *	Read from a memory buffer.
 *
 *	@arg	vcookie		the cursor (uncasted)
 *	@arg	dest		the destination buffer.
 *	@arg	size		the size to read.
 *	@return				the error, if any.
 */

int p7_membuffer_read(void *vcookie, unsigned char *dest, size_t size)
{
	p7_cursor_t *cursor = (void*)vcookie;
	const unsigned char *mem = cursor->mem;

	memcpy(dest, &mem[cursor->offset], size);
	cursor->offset += size;
	return (0);
}
