/* *****************************************************************************
 * utils/skip.c -- skip bytes in a stream.
 * Copyright (C) 2017 Thomas "Cakeisalie5" Touhey <thomas@touhey.fr>
 *
 * This file is part of libp7.
 * libp7 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3.0 of the License,
 * or (at your option) any later version.
 *
 * libp7 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with libp7; if not, see <http://www.gnu.org/licenses/>.
 * ************************************************************************** */
#include <libp7/internals.h>
#define BUFSIZE 512

/**
 *	p7_skip:
 *	Skip bytes in stream.
 *
 *	@arg	stream		the stream.
 *	@arg	size		the size of the data span to skip.
 *	@return				the error code (0 if ok).
 */

int p7_skip(p7_stream_t *stream, size_t size)
{
	uint8_t buf[BUFSIZE];
	logr_info("Skipping %" PRIuSIZE " bytes.", size);
	while (size) {
		size_t rd = min(size, BUFSIZE);
		int err = p7_read(stream, buf, rd);
		if (err) return (err);
		size -= rd;
	}
	return (0);
}
