/* *****************************************************************************
 * utils/validate.c -- elements validating utilities.
 * Copyright (C) 2016-2017 Thomas "Cakeisalie5" Touhey <thomas@touhey.fr>
 *
 * This file is part of libp7.
 * libp7 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3.0 of the License,
 * or (at your option) any later version.
 *
 * libp7 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with libp7; if not, see <http://www.gnu.org/licenses/>.
 * ************************************************************************** */
#include <libp7/internals.h>
#include <ctype.h>

/**
 *	p7_validate_filename:
 *	Validate a filename.
 *
 *	@arg	filename		the filename to validate
 *	@return					if it is validated
 */

int p7_validate_filename(const char *filename)
{
	for (size_t n = 0; filename[n]; n++)
		if (n >= 12 || !isascii(filename[n])) return (0);
	return (1);
}

/**
 *	p7_validate_dirname:
 *	Validate a directory name.
 *
 *	@arg	dirname			the directory name to validate
 *	@return					if it is validated
 */

int p7_validate_dirname(const char *dirname)
{
	for (size_t n = 0; dirname[n]; n++)
		if (n >= 9 || !isascii(dirname[n])) return (0);
	return (1);
}
